<?xml version="1.0" encoding="UTF-8"?>
<!--
********************************************************************
*  Licensed Materials - Property of IBM 
*
*  5724-C07 
*
*  (c) Copyright IBM Corp.  2001, 2002 All Rights Reserved
* 
*  US Government Users Restricted Rights - Use, duplication or
*  disclosure restricted by GSA ADP Schedule Contract with
*  IBM Corp.
*********************************************************************

 *==============================================================================
 * File, Component, Release:
 * %W%
 *
 * Version: %I%
 *==============================================================================
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:lxslt="http://xml.apache.org/xslt"
                xmlns:localizer="xalan://com.ibm.btb.tools.archive.view.XSLTLocalizer"
                exclude-result-prefixes="localizer"
                version="1.0">

<!-- *********************************************************************** 
     Output and stylesheet options.
     *********************************************************************** -->
<xsl:output method="html" omit-xml-declaration="yes" indent="yes"/>
<xsl:strip-space elements="*"/>


<!-- *********************************************************************** 
     Locale parameters and default values
     *********************************************************************** -->
<xsl:param name="language" select="'en'"/>
<xsl:param name="country" select="'US'"/>
<xsl:param name="variant"/>
<xsl:param name="bundle" select="'com.ibm.btb.tools.archive.view.ViewToolGUIResources'"/>


<!-- *********************************************************************** 
     Localizer Variable
     *********************************************************************** -->
<xsl:variable name="xsltLocalizer" select="localizer:new()"/>


<!-- *********************************************************************** 
     Localizer Initialization
     *********************************************************************** -->
<xsl:template name="stylesheetInit">
    <xsl:variable name="initReturnValue" select="localizer:initialize($xsltLocalizer, string($language), string($country), string($variant), string($bundle))"/>
</xsl:template>

<!-- *********************************************************************** 
     Root element
     *********************************************************************** -->
<xsl:template match="/">

    <!-- Initialize Localization -->
    <xsl:call-template name="stylesheetInit"/>
        <!--
        ********************************************************************
        *  Licensed Materials - Property of IBM 
        *
        *  5724-C07 
        *
        *  (c) Copyright IBM Corp.  2001, 2003 All Rights Reserved
        * 
        *  US Government Users Restricted Rights - Use, duplication or
        *  disclosure restricted by GSA ADP Schedule Contract with
        *  IBM Corp.
        *********************************************************************
        
         *==============================================================================
         * File, Component, Release:
         * src/com/ibm/btb/report/jsp/reporttool/reportHTML.jsp, TUG_AUDIT, pm_1.2
         *
         * Version: 1.33
         *==============================================================================
        -->
        <HTML>
        <HEAD>
            <TITLE><xsl:value-of select="$title"/> </TITLE>
            <LINK rel="stylesheet" type="text/css" href="{$relative}css/report_style.css"/>    
        </HEAD>
        <BODY bgcolor="#FFFFFF" onSubmit="return false">
            <!-- Recurse to the correct type of report -->
            <xsl:apply-templates select="*"/>
        </BODY>
        </HTML>
</xsl:template>
             
<!-- *********************************************************************** 
     Common Variables
     *********************************************************************** -->
<xsl:variable name="newline">
<xsl:text>
</xsl:text>
</xsl:variable>

<xsl:variable name="HTML-SPACE">
    <xsl:text>&#160;</xsl:text>
</xsl:variable>

<xsl:variable name="DIVIDER-LINE-URL" select="concat($relative,'images/dividerLine.gif')"/>

<xsl:variable name="WIDTH1" select="'96%'"/>
<xsl:variable name="WIDTH2" select="'94%'"/>
<xsl:variable name="WIDTH3" select="'92%'"/>

<xsl:variable name="SPLIT2CELL-WIDTH" select="'49%'"/>
<xsl:variable name="SPLIT2CELL-SPACING" select="'2%'"/>
<xsl:variable name="SPLIT2CELL-HALFREMAINING-WIDTH" select="'51%'"/>

<xsl:variable name="SPLIT3CELL-WIDTH" select="'32%'"/>
<xsl:variable name="SPLIT3CELL-SPACING" select="'2%'"/>



<xsl:template name="emitHeader-Section">
    <xsl:param name="sectionTitle" select="$HTML-SPACE"/>

    <TABLE width="{$WIDTH1}" border="0" cellspacing="0" cellpadding="0" align="center">
        <TR>
            <TD>
                <FONT class="subtitle">
                    <xsl:value-of select="$sectionTitle"/>
                </FONT>
            </TD>
        </TR>
        <TR>
            <TD height="2" background="{$DIVIDER-LINE-URL}"><img src="{$DIVIDER-LINE-URL}" height="2"/></TD>
        </TR>
    </TABLE>

</xsl:template>


<xsl:template name="emitHeader-Subsection">
    <xsl:param name="subsectionTitle" select="$HTML-SPACE"/>

    <TABLE width="{$WIDTH2}" border="0" cellspacing="0" cellpadding="0" align="center">
        <TR>
            <TD>
                <FONT class="subtitle">
                    <xsl:value-of select="$subsectionTitle"/>
                </FONT>
            </TD>
        </TR>
        <TR>
            <TD height="2" background="{$DIVIDER-LINE-URL}"><img src="{$DIVIDER-LINE-URL}" height="2"/></TD>
        </TR>
    </TABLE>

</xsl:template>



<xsl:template name="emitSplitCells-Section">
    <xsl:param name="name1" select="$HTML-SPACE"/>
    <xsl:param name="value1" select="$HTML-SPACE"/>
    <xsl:param name="name2" select="$HTML-SPACE"/>
    <xsl:param name="value2" select="$HTML-SPACE"/>

    <TABLE width="{$WIDTH2}" border="0" cellspacing="1" cellpadding="2" align="center">    
        <TR>
            <TH class="normal" align="left" width="{$SPLIT2CELL-WIDTH}"><xsl:value-of select="$name1"/></TH>
            <TH class="normal" align="left" width="{$SPLIT2CELL-SPACING}"><xsl:value-of select="$HTML-SPACE"/></TH>        
            <TH class="normal" align="left" width="{$SPLIT2CELL-WIDTH}"><xsl:value-of select="$name2"/></TH>
        </TR>
        <TR>
            <TD>                                                            
                <TABLE width="100%" border="1" bordercolor="#bcbcbc" cellspacing="0" cellpadding="3" align="center">
                    <TR>
                        <TD class="genericTableCellRpt">
                        <xsl:choose>
                            <xsl:when test="string-length($value1)=0">
                                <xsl:value-of disable-output-escaping="no" select="$HTML-SPACE"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of disable-output-escaping="yes" select="$value1"/>
                            </xsl:otherwise>
                        </xsl:choose>
                        </TD>                
                    </TR>            
                </TABLE>
            </TD>
            <TD><xsl:value-of select="$HTML-SPACE"/></TD>
            <TD>
                <TABLE width="100%" border="1" bordercolor="#bcbcbc" cellspacing="0" cellpadding="3" align="center">
                    <TR>
                        <TD class="genericTableCellRpt">
                        <xsl:choose>
                            <xsl:when test="string-length($value2)=0">
                                <xsl:value-of disable-output-escaping="no" select="$HTML-SPACE"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of disable-output-escaping="yes" select="$value2"/>
                            </xsl:otherwise>
                        </xsl:choose>
                        </TD>
                    </TR>            
                </TABLE>
            </TD>
        </TR>
    </TABLE>
</xsl:template>


<xsl:template name="emitSplitCellsHalf-Section">
    <xsl:param name="name1" select="$HTML-SPACE"/>
    <xsl:param name="value1" select="$HTML-SPACE"/>

    <TABLE width="{$WIDTH2}" border="0" cellspacing="1" cellpadding="2" align="center">    
        <TR>
            <TH class="normal" align="left" width="{$SPLIT2CELL-WIDTH}"><xsl:value-of select="$name1"/></TH>
            <TH class="normal" align="left" width="{$SPLIT2CELL-HALFREMAINING-WIDTH}"><xsl:value-of select="$HTML-SPACE"/></TH>
        </TR>
        <TR>
            <TD>                                                            
                <TABLE width="100%" border="1" bordercolor="#bcbcbc" cellspacing="0" cellpadding="3" align="center">
                    <TR>
                        <TD class="genericTableCellRpt">
                        <xsl:choose>
                            <xsl:when test="string-length($value1)=0">
                                <xsl:value-of disable-output-escaping="no" select="$HTML-SPACE"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of disable-output-escaping="yes" select="$value1"/>
                            </xsl:otherwise>
                        </xsl:choose>
                        </TD>
                    </TR>            
                </TABLE>
            </TD>
            <TD><xsl:value-of select="$HTML-SPACE"/></TD>
        </TR>
    </TABLE>
</xsl:template>


<xsl:template name="emitSplit3Cells-Subsection">
    <xsl:param name="name1" select="$HTML-SPACE"/>
    <xsl:param name="value1" select="$HTML-SPACE"/>
    <xsl:param name="name2" select="$HTML-SPACE"/>
    <xsl:param name="value2" select="$HTML-SPACE"/>
    <xsl:param name="name3" select="$HTML-SPACE"/>
    <xsl:param name="value3" select="$HTML-SPACE"/>

    <TABLE width="{$WIDTH3}" border="0" cellspacing="1" cellpadding="2" align="center">    
        <TR>
            <TH class="normal" align="left" width="{$SPLIT3CELL-WIDTH}"><xsl:value-of select="$name1"/></TH>
            <TH class="normal" align="left" width="{$SPLIT3CELL-SPACING}"><xsl:value-of select="$HTML-SPACE"/></TH>        
            <TH class="normal" align="left" width="{$SPLIT3CELL-WIDTH}"><xsl:value-of select="$name2"/></TH>
            <TH class="normal" align="left" width="{$SPLIT3CELL-SPACING}"><xsl:value-of select="$HTML-SPACE"/></TH>     
            <TH class="normal" align="left" width="{$SPLIT3CELL-WIDTH}"><xsl:value-of select="$name3"/></TH>    
        </TR>
        <TR>
            <TD>
                <TABLE width="100%" border="1" bordercolor="#bcbcbc" cellspacing="0" cellpadding="3" align="center">
                    <TR>
                        <TD class="genericTableCellRpt">
                        <xsl:choose>
                            <xsl:when test="string-length($value1)=0">
                                <xsl:value-of disable-output-escaping="no" select="$HTML-SPACE"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of disable-output-escaping="yes" select="$value1"/>
                            </xsl:otherwise>
                        </xsl:choose>
                        </TD>
                    </TR>            
                </TABLE>
            </TD>
            <TD><xsl:value-of select="$HTML-SPACE"/></TD>
            <TD>
                <TABLE width="100%" border="1" bordercolor="#bcbcbc" cellspacing="0" cellpadding="3" align="center">
                    <TR>
                        <TD class="genericTableCellRpt">
                        <xsl:choose>
                            <xsl:when test="string-length($value2)=0">
                                <xsl:value-of disable-output-escaping="no" select="$HTML-SPACE"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of disable-output-escaping="yes" select="$value2"/>
                            </xsl:otherwise>
                        </xsl:choose>
                        </TD>
                    </TR>            
                </TABLE>
            </TD>    
            <TD><xsl:value-of select="$HTML-SPACE"/></TD>
            <TD>
                <TABLE width="100%" border="1" bordercolor="#bcbcbc" cellspacing="0" cellpadding="3" align="center">
                    <TR>
                        <TD class="genericTableCellRpt">
                        <xsl:choose>
                            <xsl:when test="string-length($value3)=0">
                                <xsl:value-of disable-output-escaping="no" select="$HTML-SPACE"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of disable-output-escaping="yes" select="$value3"/>
                            </xsl:otherwise>
                        </xsl:choose>
                        </TD>
                    </TR>            
                </TABLE>
            </TD>
        </TR>
    </TABLE>
</xsl:template>


<xsl:template name="emitSpacing-Section">
    <BR/>
</xsl:template>

<xsl:template name="emitSmallSpacing">
    <TABLE cellspacing="2" cellpadding="0">
        <TR>
            <TD></TD>
        </TR>
    </TABLE>
</xsl:template>

<xsl:template name="emitMediumSpacing">
    <TABLE cellspacing="4" cellpadding="0">
        <TR>
            <TD></TD>
        </TR>
    </TABLE>
</xsl:template>

<xsl:template name="emitLabel-Section">
    <xsl:param name="label" select="$HTML-SPACE"/>
    
    <TABLE width="{$WIDTH2}" border="0" cellspacing="1" cellpadding="2" align="center">    
        <TR>
            <TH class="normal" align="left"><xsl:value-of disable-output-escaping="yes" select="$label"/></TH>
        </TR>
    </TABLE>

</xsl:template>


<xsl:template name="emitLabel-Subsection">
    <xsl:param name="label" select="$HTML-SPACE"/>
    
    <TABLE width="{$WIDTH3}" border="0" cellspacing="1" cellpadding="2" align="center">    
        <TR>
            <TH class="normal" align="left"><xsl:value-of disable-output-escaping="yes" select="$label"/></TH>
        </TR>
    </TABLE>

</xsl:template>

<!-- *************************************************************************************************************
     *                                    MULTI POLICY OPTIONS LOOKUP TEMPLATE                                   *
     *************************************************************************************************************-->
<xsl:template name="lookupMultiPolicy">
    <xsl:param name="flag"/>
    
    <xsl:choose>
        <xsl:when test="$flag='required'">
            <xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_MULTIPOLICY_REQUIRED'))"/>
        </xsl:when>        
        <xsl:when test="$flag='isconsented'">
            <xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_MULTIPOLICY_ISCONSENTED'))"/>
        </xsl:when>        
        <xsl:otherwise>
            <xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_MULTIPOLICY_OPTIONAL'))"/>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>
<!-- *************************************************************************************************************
     *                                    Conformance Flag Lookup Template                                       *
     *************************************************************************************************************-->
<xsl:template name="lookupConformanceFlag">
    <xsl:param name="flag"/>
    
    <xsl:choose>
        <xsl:when test="$flag='true'">
            <xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_BOOLEAN_TRUE'))"/>
        </xsl:when>
        <xsl:when test="$flag='false'">
            <xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_BOOLEAN_FALSE'))"/>
        </xsl:when>        
        <xsl:when test="$flag='denied'">
            <xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_DENIED'))"/>
        </xsl:when>        
        <xsl:when test="$flag='error-denied'">
            <xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_ERROR_DENIED'))"/>
        </xsl:when>        
        <xsl:otherwise>
            <xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_CONFORMANCE_ERROR'))"/>
        </xsl:otherwise>
    </xsl:choose>

</xsl:template>
<!-- *********************************************************************** 
     Policy Consent Lookup Template (Used by access record report)
     *********************************************************************** --> 
<xsl:template name="lookupPolicyConsent">
    <xsl:param name="consent"/>
    
    <xsl:choose>
        <xsl:when test="$consent='explicit'">
            <xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_POLICYCONSENT_EXPLICIT'))"/>
        </xsl:when>
        <xsl:otherwise>
            <xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_POLICYCONSENT_IMPLICIT'))"/>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>

</xsl:stylesheet>
