<?xml version="1.0" encoding="UTF-8"?>
<!--
********************************************************************
*  Licensed Materials - Property of IBM 
*
*  5724-C07 
*
*  (c) Copyright IBM Corp.  2001, 2004 All Rights Reserved
* 
*  US Government Users Restricted Rights - Use, duplication or
*  disclosure restricted by GSA ADP Schedule Contract with
*  IBM Corp.
*********************************************************************

*********************************************************************
* File, Component, Release:
* %W%
*
* Version: %I%
*
* Date and Time File was last checked in:       %E% %U%
* Date and Time File was extracted/checked out: %D% %T%
*
* Description:
*
* Change History:
*
* mm/dd/yyyy userid   track    change history description here
* ********** ******   *****    **************************************
*            plachco  ?????   Intial Code Creation
* 02/05/2004 jharter  d6634    Call out to count of records processed
*
*********************************************************************
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:lxslt="http://xml.apache.org/xslt"
                xmlns:localizer="xalan://com.ibm.btb.tools.archive.view.XSLTLocalizer"
                exclude-result-prefixes="localizer"
                version="1.0">

<!-- *********************************************************************** 
     Imports for individual report stylesheets
     *********************************************************************** -->
<xsl:import href="common.xsl"/>
<xsl:variable name="basedir"   select="'../'"/>
<xsl:param name="index"/>
<xsl:variable name="relative"   select="localizer:getRootRelativeToDetailedPage($xsltLocalizer,$index)"/>
<xsl:variable name="title" select="localizer:getSummaryTitle($xsltLocalizer, $index)"/>


<!-- *********************************************************************** 
     HTML Variables
     *********************************************************************** -->
<xsl:variable name="MONITOR-TIME-WIDTH" select="'50%'"/>
<xsl:variable name="SERVER-TIME-WIDTH"  select="'50%'"/>
<xsl:variable name="MASTER-KEY-WIDTH"       select="'50%'"/>
<xsl:variable name="MASTER-KEY-VALUE-WIDTH" select="'50%'"/>
<xsl:variable name="ACCESS-ACCESSOR-INFORMATION-KEY-WIDTH"   select="'50%'"/>
<xsl:variable name="ACCESS-ACCESSOR-INFORMATION-VALUE-WIDTH" select="'50%'"/>
<xsl:variable name="ACCESS-MONITOR-EVAL-CONDRULEDESC-WIDTH" select="'65%'"/>
<xsl:variable name="ACCESS-MONITOR-EVAL-RESULT-WIDTH"       select="'15%'"/>
<xsl:variable name="ACCESS-ACCESSOR-RESULTINGID-WIDTH" select="'20%'"/>
<xsl:variable name="ACCESS-ACCESSOR-KEY-WIDTH"         select="'40%'"/>
<xsl:variable name="ACCESS-ACCESSOR-VALUE-WIDTH"       select="'40%'"/>
<xsl:variable name="SUBMISSION-GOVPOLICY-SLOC-WIDTH"    select="'35%'"/>
<xsl:variable name="SUBMISSION-GOVPOLICY-NAME-WIDTH"    select="'35%'"/>
<xsl:variable name="SUBMISSION-GOVPOLICY-VERSION-WIDTH" select="'20%'"/>
<xsl:variable name="SUBMISSION-GOVPOLICY-CONSENT-WIDTH" select="'10%'"/>
<xsl:variable name="ACCESS-TYPEMAP-SLOC-WIDTH"        select="'25%'"/>
<xsl:variable name="ACCESS-TYPEMAP-TYPE-WIDTH"        select="'60%'"/>
<xsl:variable name="ACCESS-TYPEMAP-CONFORMANCE-WIDTH" select="'15%'"/>
<xsl:variable name="ACCESS-TYPEMAP-TYPE-NAME-WIDTH"          select="'25%'"/>
<xsl:variable name="ACCESS-TYPEMAP-TYPE-POLICYNAME-WIDTH"    select="'15%'"/>
<xsl:variable name="ACCESS-TYPEMAP-TYPE-POLICYVERSION-WIDTH" select="'10%'"/>
<xsl:variable name="ACCESS-TYPEMAP-TYPE-CONSENT-WIDTH"       select="'10%'"/>
<xsl:variable name="ACCESS-TYPEMAP-TYPE-MULTIPOLICY-WIDTH"   select="'10%'"/>

<xsl:key name="id" match="ar" use="@id"/>
<xsl:key name="monitorUID" match="request" use="minfo/@muid"/>


<!-- *************************************************************************************************************
     *                                      D E T A I L E D    A C C E S S                                       *
     *************************************************************************************************************-->
<xsl:template match="ar">        
    <xsl:value-of select="localizer:bumpRecordCount($xsltLocalizer)"/>  <!-- jlh 6634 -->
    <xsl:variable name="RID" select="@id"/>
    
    <xsl:variable name="mregdate" select="../minfo/@mregdate"/>
    
    <xsl:variable name="mregdate-string">
       <xsl:value-of select="localizer:formatDateShort($xsltLocalizer, string($mregdate))"/>
       <xsl:value-of select="$HTML-SPACE"/>
       <xsl:value-of select="localizer:formatTimeLong($xsltLocalizer, string($mregdate))"/>
    </xsl:variable>               
    
    <!-- Link to this record -->
    <A name="{$RID}">
        <xsl:call-template name="emitSmallSpacing"/>
    </A>
    <!-- Access Section Header -->
    <xsl:variable name="monitorName" select="../minfo/@mname"/>
    <xsl:variable name="accessLabel" select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_ACCESS_HEADING'), $monitorName,$mregdate-string)"/>
    <xsl:call-template name="emitHeader-Section">
       <xsl:with-param name="sectionTitle" select="$accessLabel"/>
    </xsl:call-template>               
    <xsl:call-template name="emitSmallSpacing"/>
   
    <!-- Emit table header -->           
   <TABLE cellSpacing="0" cellPadding="0" width="94%" align="center" border="0">
      <TBODY>
         <TR>
            <TD>
               <!-- Timestamp Section -->
               <xsl:call-template name="timestamps"/>
               
               <!-- Data Owner Section -->
               <xsl:call-template name="data-owner"/>
               
               <!-- Eval Result Section -->
               <xsl:apply-templates select="erp"/>
               
               <!-- Type Mappings Section -->
               <xsl:call-template name="type-mappings">        
			       <xsl:with-param name="RID" select="$RID"/>
			    </xsl:call-template>               
     
               <!-- Authid Mappings Section -->
               <xsl:call-template name="authid-mappings"/>        
               
               <!-- Purpose Mappings Section -->
               <xsl:call-template name="purpose-mappings"/>        
               
               <!-- Accessor Info Section -->
               <xsl:call-template name="accessor-info"/>        
               
               <!-- Notes Section -->
               <xsl:call-template name="notes"/>        
            </TD>
         </TR>
      </TBODY>
    </TABLE>

</xsl:template>              

<!-- *************************************************************************************************************
     *                                          T I M E S T A M P S                                              *
     *************************************************************************************************************-->
<xsl:template name="timestamps">
    
   <xsl:variable name="access-time" select="../@mtime"/>
   
   <xsl:variable name="accessDateTimeString">
     <xsl:value-of select="localizer:formatDateShort($xsltLocalizer, string($access-time))"/>
     <xsl:value-of select="$HTML-SPACE"/>
     <xsl:value-of select="localizer:formatTimeLong($xsltLocalizer, string($access-time))"/>    
   </xsl:variable>
     
   <xsl:variable name="confCheckTimestamp" select="../@server-time"/>
   
   <xsl:variable name="serverDateTimeString">
     <xsl:value-of select="localizer:formatDateShort($xsltLocalizer, string($confCheckTimestamp))"/>
     <xsl:value-of select="$HTML-SPACE"/>
     <xsl:value-of select="localizer:formatTimeLong($xsltLocalizer, string($confCheckTimestamp))"/>    
   </xsl:variable>
    
  <!-- Emit Timestamps segment header -->
   <xsl:variable name="timestampLabel" select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_DETAILED_TIMESTAMPS'))"/>
   <xsl:call-template name="emitHeader-Section">
       <xsl:with-param name="sectionTitle" select="$timestampLabel"/>
   </xsl:call-template>               
   <xsl:call-template name="emitSmallSpacing"/>
   
   <TABLE borderColor="#bcbcbc" cellSpacing="0" cellPadding="2" width="96%" align="center" border="1">
   <TBODY>
      <!-- Emit Timestamp Infomation header -->
      <TR>
          <TH width="{$MONITOR-TIME-WIDTH}" class="genericHeaderCellRpt"><CENTER><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_TABLES_MONITOR_TIME'))"/></CENTER></TH>
          <TH width="{$SERVER-TIME-WIDTH}" class="genericHeaderCellRpt"><CENTER><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_TABLES_SERVER_TIME'))"/></CENTER></TH>
      </TR>

      <!-- Emit Timestamp Information-->
      <TR>
         <TD class="genericTableCellRpt"><xsl:value-of select="$accessDateTimeString"/></TD>
         <TD class="genericTableCellRpt"><xsl:value-of select="$serverDateTimeString"/></TD>
      </TR>
   </TBODY>
   </TABLE>

</xsl:template>

<!-- *************************************************************************************************************
     *                                          D A T A   O W N E R                                              *
     *************************************************************************************************************-->
<xsl:template name="data-owner">
    
    <!-- Retrieve sloc name of master key from the access-record -->
    <xsl:variable name="masterKeyString">                    
        <xsl:choose>
            <xsl:when test="../minfo/@mkey">
                <xsl:value-of select="../minfo/@mkey"/>            
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$HTML-SPACE"/>
            </xsl:otherwise>
        </xsl:choose> 
    </xsl:variable>
    
    <!-- Retrieve value of master key from the access-record -->
    <xsl:variable name="masterValueString">                    
        <xsl:choose>
            <xsl:when test="../@mkval">
                <xsl:value-of select="../@mkval"/>            
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$HTML-SPACE"/>
            </xsl:otherwise>
        </xsl:choose> 
    </xsl:variable>
                    
  <!-- Emit Data Owner Information segment header -->
   <xsl:call-template name="emitSmallSpacing"/>
   <xsl:variable name="subSectionLabel" select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_DETAILED_DATAOWNER'))"/>
   <xsl:call-template name="emitHeader-Section">
       <xsl:with-param name="sectionTitle" select="$subSectionLabel"/>
   </xsl:call-template>               
   <xsl:call-template name="emitSmallSpacing"/>
  
   <TABLE borderColor="#bcbcbc" cellSpacing="0" cellPadding="2" width="96%" align="center" border="1">
   <TBODY>
      <TR>
         <TH width="{$MASTER-KEY-WIDTH}" class="genericHeaderCellRpt"><CENTER><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_TABLES_MASTER_KEY'))"/></CENTER></TH>
         <TH width="{$MASTER-KEY-VALUE-WIDTH}" class="genericHeaderCellRpt"><CENTER><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_TABLES_VALUE'))"/></CENTER></TH>
      </TR>      
      <!-- Emit Master Key Information -->
      <TR>
         <TD class="genericTableCellRpt"><xsl:value-of select="$masterKeyString"/></TD>
         <TD class="genericTableCellRpt"><xsl:value-of select="$masterValueString"/></TD>
      </TR>
   </TBODY>
   </TABLE>
   
</xsl:template>

<!-- *************************************************************************************************************
     *                                            N O T E S                                                      *
     *************************************************************************************************************-->
<xsl:template name="notes">
    
    <!-- Retrieve notes from the request -->
   <xsl:variable name="additionalNotes">
     <xsl:choose>
         <xsl:when test="string-length(../@mnotes) != 0">
             <xsl:value-of select="../@mnotes"/>            
         </xsl:when>
         <xsl:otherwise>
             <xsl:value-of select="$HTML-SPACE"/>
         </xsl:otherwise>
     </xsl:choose> 
   </xsl:variable>
  
  <!-- Emit Notes segment header -->
   <xsl:call-template name="emitSmallSpacing"/>
   <xsl:variable name="subSectionLabel" select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_TABLES_NOTES'))"/>
   <xsl:call-template name="emitHeader-Section">
       <xsl:with-param name="sectionTitle" select="$subSectionLabel"/>
   </xsl:call-template>               
   <xsl:call-template name="emitSmallSpacing"/>
  
   <TABLE borderColor="#bcbcbc" cellSpacing="0" cellPadding="2" width="96%" align="center" border="1">
   <TBODY>
     <!-- Emit Additional Notes -->
     <TR>                
         <TD class="genericTableCellRpt"><xsl:value-of select="$additionalNotes"/></TD>        
     </TR>
   </TBODY>
   </TABLE>

</xsl:template>

<!-- *************************************************************************************************************
     *                                     A C C E S S O R    I N F O                                            *
     *************************************************************************************************************-->
<xsl:template name="accessor-info">
    
  <!-- Emit Accessor Info segment header -->
   <xsl:call-template name="emitSmallSpacing"/>
   <xsl:variable name="subSectionLabel" select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_DETAILED_ACCESSORINFO'))"/>
   <xsl:call-template name="emitHeader-Section">
       <xsl:with-param name="sectionTitle" select="$subSectionLabel"/>
   </xsl:call-template>               
   <xsl:call-template name="emitSmallSpacing"/>
  
   <TABLE borderColor="#bcbcbc" cellSpacing="0" cellPadding="2" width="96%" align="center" border="1">
   <TBODY>
     <!-- Emit Key Value pairs -->
     <TR>                
         <TH class="genericHeaderCellRpt" width="${ACCESS-ACCESSOR-INFORMATION-KEY-WIDTH}"><CENTER><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_TABLES_KEY'))"/></CENTER></TH>
         <TH class="genericHeaderCellRpt" width="${ACCESS-ACCESSOR-INFORMATION-VALUE-WIDTH}"><CENTER><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_TABLES_VALUE'))"/></CENTER></TH>
     </TR>
    <xsl:choose>
        <xsl:when test="../accessor-info/accessor-info-data">
            <!-- Go through each accessor-info-data element for this request's accessor -->
            
            <xsl:for-each select="../accessor-info/accessor-info-data">
                <!-- Retrieve Accessor Info Key from the request's accessor -->
               <xsl:variable name="key">
                 <xsl:choose>
                     <xsl:when test="string-length(@key) != 0">
                         <xsl:value-of select="@key"/>            
                     </xsl:when>
                     <xsl:otherwise>
                         <xsl:value-of select="$HTML-SPACE"/>
                     </xsl:otherwise>
                 </xsl:choose> 
               </xsl:variable>              
                <!-- Retrieve Accessor Info Value from the request's accessor -->
               <xsl:variable name="value">
                 <xsl:choose>
                     <xsl:when test="string-length(@value) != 0">
                         <xsl:value-of select="@value"/>            
                     </xsl:when>
                     <xsl:otherwise>
                         <xsl:value-of select="$HTML-SPACE"/>
                     </xsl:otherwise>
                 </xsl:choose> 
               </xsl:variable>              
               
               <TR>
                   <TD class="genericTableCellRpt"><xsl:value-of select="$key"/></TD>        
                   <TD class="genericTableCellRpt"><xsl:value-of select="$value"/></TD>        
               </TR>
            </xsl:for-each>                          
        </xsl:when>
        <!-- In case that the monitor sent no accessor info key-value pairs -->
        <xsl:otherwise>
            <TR>
                <TD class="genericTableCellRpt"><xsl:value-of select="$HTML-SPACE"/></TD>
                <TD class="genericTableCellRpt"><xsl:value-of select="$HTML-SPACE"/></TD>				
            </TR>	        
        </xsl:otherwise>
    </xsl:choose>         
   </TBODY>
   </TABLE>

</xsl:template>

<!-- *************************************************************************************************************
     *                            M O N I T O R     E V A L U A T I O N     R U L E S                            *
     *************************************************************************************************************-->
<!-- POLICY -->
<xsl:template match="erp">
    
   <!-- Retrieve Policy Name from the Eval Result -->
   <xsl:variable name="pname">
     <xsl:choose>
         <xsl:when test="string-length(@pname) != 0">
             <xsl:value-of select="@pname"/>            
         </xsl:when>
         <xsl:otherwise>
             <xsl:value-of select="$HTML-SPACE"/>
         </xsl:otherwise>
     </xsl:choose> 
   </xsl:variable>              
   <!-- Retrieve Policy Version from the Eval Result -->
   <xsl:variable name="pver">
     <xsl:choose>
         <xsl:when test="string-length(@pver) != 0">
             <xsl:value-of select="@pver"/>            
         </xsl:when>
         <xsl:otherwise>
             <xsl:value-of select="$HTML-SPACE"/>
         </xsl:otherwise>
     </xsl:choose> 
   </xsl:variable>              
  <!-- Emit Eval Rule segment header for the current policy(version) -->
   <xsl:call-template name="emitSmallSpacing"/>
   <xsl:variable name="subSectionLabelTemp" select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_DETAILED_MONITOREVALS'))"/>   
   <xsl:variable name="subSectionLabel" select="concat($subSectionLabelTemp,$pname,'(',$pver,')')"/>
   <xsl:call-template name="emitHeader-Section">
       <xsl:with-param name="sectionTitle" select="$subSectionLabel"/>
   </xsl:call-template>               
   <xsl:call-template name="emitSmallSpacing"/>
  
   <TABLE borderColor="#bcbcbc" cellSpacing="0" cellPadding="2" width="96%" align="center" border="1">
   <TBODY>
      <!-- Emit the Eval Rule statements -->
      <xsl:apply-templates select="./ers"/>      
   </TBODY>
   </TABLE>
</xsl:template>
<!-- STATEMENT -->
<xsl:template match="ers">
    
   <!-- Retrieve Statement Description from the Eval Result -->
   <xsl:variable name="desc">
     <xsl:choose>
         <xsl:when test="string-length(@desc) != 0">
             <xsl:value-of select="@desc"/>            
         </xsl:when>
         <xsl:otherwise>
             <xsl:value-of select="$HTML-SPACE"/>
         </xsl:otherwise>
     </xsl:choose> 
   </xsl:variable>              
      
      <TR>
        <TH class="genericHeaderCellRpt"><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_DETAILED_STATEMENTNAME'))"/></TH>
        <TD class="genericTableCellRpt" colspan="2"><xsl:value-of select="$desc"/></TD>
      </TR>
      <TR>
        <TH class="genericHeaderCellRpt"><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_DETAILED_GROUPPURPOSENAME'))"/></TH>
        <TH class="genericHeaderCellRpt" width="${ACCESS-MONITOR-EVAL-CONDRULEDESC-WIDTH}"><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_DETAILED_CRDESCRIPTION'))"/></TH>
        <TH class="genericHeaderCellRpt"><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_DETAILED_EVALRESULT'))"/></TH>
      </TR>
      <!-- Emit the Eval Rule statements -->
      <xsl:apply-templates select="./er-cr"/>      

</xsl:template>
<!-- CONDITION RULE -->
<xsl:template match="er-cr">
    
   <!-- Retrieve Condition Rule Description from the Eval Result -->
   <xsl:variable name="desc">
     <xsl:choose>
         <xsl:when test="string-length(@desc) != 0">
             <xsl:value-of select="@desc"/>            
         </xsl:when>
         <xsl:otherwise>
             <xsl:value-of select="$HTML-SPACE"/>
         </xsl:otherwise>
     </xsl:choose> 
   </xsl:variable>              
   <!-- Retrieve Condition Rule Result from the Eval Result -->
   <xsl:variable name="result">
     <xsl:choose>
         <xsl:when test="string-length(@result) != 0">
             <xsl:value-of select="@result"/>            
         </xsl:when>
         <xsl:otherwise>
             <xsl:value-of select="$HTML-SPACE"/>
         </xsl:otherwise>
     </xsl:choose> 
   </xsl:variable>              
   <!-- Retrieve Condition Rule Parent Name from the Eval Result -->
   <xsl:variable name="parent-name">
     <xsl:choose>
         <xsl:when test="string-length(@gpname) != 0">
             <xsl:value-of select="@gpname"/>            
         </xsl:when>
         <xsl:otherwise>
             <xsl:value-of select="$HTML-SPACE"/>
         </xsl:otherwise>
     </xsl:choose> 
   </xsl:variable>              
      
     <TR>
       <TD class="genericTableCellRpt"><xsl:value-of select="$parent-name"/></TD>
       <TD class="genericTableCellRpt"><xsl:value-of select="$desc"/></TD>
       <TD class="genericTableCellRpt" width="${ACCESS-MONITOR-EVAL-RESULT-WIDTH}"><xsl:value-of select="$result"/></TD>
     </TR>

</xsl:template>

<!-- *************************************************************************************************************
     *                                    A U T H I D    M A P P I N G S                                         *
     *************************************************************************************************************-->
<xsl:template name="authid-mappings">
     <!-- Retrieve accessor key the authid-info contained in the access-record -->
     <xsl:variable name="keyString">
         <xsl:choose>
             <xsl:when test="../authid-info/@key and (string-length(../authid-info/@key) != 0)">
                 <xsl:value-of select="../authid-info/@key"/>
             </xsl:when>
             <xsl:otherwise>
                 <xsl:value-of select="$HTML-SPACE"/>
             </xsl:otherwise>
         </xsl:choose> 
     </xsl:variable>

     <!-- Retrieve accessor value for the auth-info contained in the access-record -->
     <xsl:variable name="valueString">
         <xsl:choose>
             <xsl:when test="../authid-info/@value and (string-length(../authid-info/@value) != 0)">
                 <xsl:value-of select="../authid-info/@value"/>
             </xsl:when>
             <xsl:otherwise>
                 <xsl:value-of select="$HTML-SPACE"/>
             </xsl:otherwise>
         </xsl:choose> 
     </xsl:variable>
     <!-- Retrieve matching authid contained in the access-record -->
     <xsl:variable name="accessIdString">
         <xsl:choose>
             <xsl:when test="../authid-info/@authid and (string-length(../authid-info/@authid) != 0)">
                 <xsl:value-of select="../authid-info/@authid"/>
             </xsl:when>
             <xsl:otherwise>
                 <xsl:value-of select="$HTML-SPACE"/>
             </xsl:otherwise>
         </xsl:choose> 
     </xsl:variable>

  <!-- Emit Authid Mappings segment header -->
   <xsl:call-template name="emitSmallSpacing"/>
   <xsl:variable name="subSectionLabel" select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_DETAILED_ACCESSID'))"/>
   <xsl:call-template name="emitHeader-Section">
       <xsl:with-param name="sectionTitle" select="$subSectionLabel"/>
   </xsl:call-template>               
   <xsl:call-template name="emitSmallSpacing"/>
  
   <TABLE borderColor="#bcbcbc" cellSpacing="0" cellPadding="2" width="96%" align="center" border="1">
   <TBODY>
     <TR>
         <TH class="genericHeaderCellRpt" width="${ACCESS-ACCESSOR-KEY-WIDTH}"><CENTER><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_TABLES_KEY'))"/></CENTER></TH>
         <TH class="genericHeaderCellRpt" width="${ACCESS-ACCESSOR-VALUE-WIDTH}"><CENTER><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_TABLES_VALUE'))"/></CENTER></TH>
         <TH class="genericHeaderCellRpt" width="${ACCESS-ACCESSOR-RESULTINGID-WIDTH}"><CENTER><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_TABLES_ACCESSOR_RESULTING_ACCESSID'))"/></CENTER></TH>
     </TR>
     <TR>
         <TD class="genericTableCellRpt"><xsl:value-of select="$keyString"/></TD>
         <TD class="genericTableCellRpt"><xsl:value-of select="$valueString"/></TD>
         <TD class="genericTableCellRpt"><xsl:value-of select="$accessIdString"/></TD>
     </TR>
   </TBODY>
   </TABLE>
</xsl:template>

<!-- *************************************************************************************************************
     *                                      P U R P O S E   M A P P I N G S                                      *
     *************************************************************************************************************-->
<xsl:template name="purpose-mappings">
    
    <!-- Retrieve accessor purpose key contained in the access-record -->
    <xsl:variable name="keyString">
        <xsl:choose>
            <xsl:when test="../purpose/@key and (string-length(../purpose/@key) != 0)">
                <xsl:value-of select="../purpose/@key"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$HTML-SPACE"/>
            </xsl:otherwise>
        </xsl:choose> 
    </xsl:variable>
    
    <!-- Retrieve accessor value for the purpose contained in the access-record -->
    <xsl:variable name="valueString">
        <xsl:choose>
            <xsl:when test="../purpose/@value and (string-length(../purpose/@value) != 0)">
                <xsl:value-of select="../purpose/@value"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$HTML-SPACE"/>
            </xsl:otherwise>
        </xsl:choose> 
    </xsl:variable>
             
  <!-- Emit Purpose Mappings segment header -->
   <xsl:call-template name="emitSmallSpacing"/>
   <xsl:variable name="subSectionLabel" select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_DETAILED_PURPOSEMAP'))"/>
   <xsl:call-template name="emitHeader-Section">
       <xsl:with-param name="sectionTitle" select="$subSectionLabel"/>
   </xsl:call-template>               
   <xsl:call-template name="emitSmallSpacing"/>
  
   <TABLE borderColor="#bcbcbc" cellSpacing="0" cellPadding="2" width="96%" align="center" border="1">
   <TBODY>
             
    <TR>
        <TH class="genericHeaderCellRpt"><CENTER><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_TABLES_KEY'))"/></CENTER></TH>
        <TH class="genericHeaderCellRpt"><CENTER><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_TABLES_VALUE'))"/></CENTER></TH>
        <TH class="genericHeaderCellRpt"><CENTER><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_TABLES_ACCESSOR_PURPOSE'))"/></CENTER></TH>
        <TH class="genericHeaderCellRpt"><CENTER><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_TABLES_TYPE_POLICYNAME'))"/></CENTER></TH>
        <TH class="genericHeaderCellRpt"><CENTER><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_TABLES_TYPE_POLICYVERSION'))"/></CENTER></TH>				
    </TR>
    
    <xsl:choose>
    
        <xsl:when test="../purpose/ppurpose">
        
            <!-- Go through each ppurpose element for this access record -->
            <xsl:for-each select="../purpose/ppurpose">
                
                <!-- Retrieve purpose name for the current ppurpose element -->
                <xsl:variable name="purposeName">
                    <xsl:choose>
                        <xsl:when test="@name and (string-length(@name) != 0)">
                            <xsl:value-of select="@name"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="$HTML-SPACE"/>
                        </xsl:otherwise>
                    </xsl:choose> 
                </xsl:variable>
                
                <!-- Retrieve policy version for the current ppurpose element -->
                <xsl:variable name="policyVersion">
                    <xsl:choose>
                        <xsl:when test="@pver and (string-length(@pver) != 0)">
                            <xsl:value-of select="@pver"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="$HTML-SPACE"/>
                        </xsl:otherwise>
                    </xsl:choose> 
                </xsl:variable>
                
                <!-- Retrieve policy name for the current ppurpose element -->
                <xsl:variable name="policyName">
                    <xsl:choose>
                        <xsl:when test="@pname and (string-length(@pname) != 0)">
                            <xsl:value-of select="@pname"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="$HTML-SPACE"/>
                        </xsl:otherwise>
                    </xsl:choose> 
                </xsl:variable>
                
                <xsl:choose>
                
                    <!-- The very first element includes the purpose key and value -->
                    <xsl:when test="position()=1">		 
                       
                        <!-- Retrieve accessor key for purpose contained in the access-record -->
                        <xsl:variable name="purposeKeyString">
                            <xsl:choose>
                                <xsl:when test="../@key and (string-length(../@key) != 0)">
                                    <xsl:value-of select="../@key"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="$HTML-SPACE"/>
                                </xsl:otherwise>
                            </xsl:choose> 
                        </xsl:variable>
                        
                        <xsl:variable name="purposeValueString">
                            <xsl:choose>
                                <xsl:when test="../@value and (string-length(../@value) != 0)">
                                    <xsl:value-of select="../@value"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="$HTML-SPACE"/>
                                </xsl:otherwise>
                            </xsl:choose> 
                        </xsl:variable>

					    <xsl:variable name="numPurposes">
					        <xsl:value-of select="count(../ppurpose)"/>
					    </xsl:variable>
                            
                        <TR>
                            <TD class="genericTableCellRpt" rowspan="{$numPurposes}"><xsl:value-of select="$purposeKeyString"/></TD>
                            <TD class="genericTableCellRpt" rowspan="{$numPurposes}"><xsl:value-of select="$purposeValueString"/></TD>
                            <TD class="genericTableCellRpt"><xsl:value-of select="$purposeName"/></TD>
                            <TD class="genericTableCellRpt"><xsl:value-of select="$policyName"/></TD>
                            <TD class="genericTableCellRpt"><xsl:value-of select="$policyVersion"/></TD>				
                        </TR>
                            
                    </xsl:when>
                    
                    <!-- The 2nd,3rd,etc elements are plain vanilla -->
                    <xsl:otherwise>
                        <TR>
                            <TD class="genericTableCellRpt"><xsl:value-of select="$purposeName"/></TD>
                            <TD class="genericTableCellRpt"><xsl:value-of select="$policyName"/></TD>
                            <TD class="genericTableCellRpt"><xsl:value-of select="$policyVersion"/></TD>				
                        </TR>								
                    </xsl:otherwise>
                    
                </xsl:choose>
                
            </xsl:for-each>                          
        
        </xsl:when>
        
        <xsl:otherwise>
        
            <TR>
                <TD class="genericTableCellRpt"><xsl:value-of select="$HTML-SPACE"/></TD>
                <TD class="genericTableCellRpt"><xsl:value-of select="$HTML-SPACE"/></TD>				
                <TD class="genericTableCellRpt"><xsl:value-of select="$HTML-SPACE"/></TD>            
                <TD class="genericTableCellRpt"><xsl:value-of select="$HTML-SPACE"/></TD>				
                <TD class="genericTableCellRpt"><xsl:value-of select="$HTML-SPACE"/></TD>            
            </TR>	        
        
        </xsl:otherwise>
    
    </xsl:choose>         
   </TBODY>
   </TABLE>
    
</xsl:template>

<!-- *************************************************************************************************************
     *                                     T Y P E       M A P P I N G S                                         *
     *************************************************************************************************************-->
<xsl:template name="type-mappings">
	<xsl:param name="RID"/>
	
    <xsl:variable name="slocName">
        <xsl:choose>
            <xsl:when test="key('id',$RID)[1]/@slname">
                <xsl:value-of select="key('id',$RID)[1]/@slname"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$HTML-SPACE"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    
    <xsl:variable name="numTypes">
        <xsl:value-of select="count(key('id',$RID)[1]/pii)"/>
    </xsl:variable>

    <xsl:variable name="typeName1">
        <xsl:choose>
            <xsl:when test="key('id',$RID)[1]/pii[1]/@type-name">
                <xsl:value-of select="key('id',$RID)[1]/pii[1]/@type-name"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$HTML-SPACE"/>
            </xsl:otherwise>
        </xsl:choose> 
    </xsl:variable>

    <xsl:variable name="policyName1">
        <xsl:choose>
            <xsl:when test="key('id',$RID)[1]/pii[1]/@pname">
                <xsl:value-of select="key('id',$RID)[1]/pii[1]/@pname"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$HTML-SPACE"/>
            </xsl:otherwise>
        </xsl:choose> 
    </xsl:variable>

    <xsl:variable name="policyVersion1">
        <xsl:choose>
            <xsl:when test="key('id',$RID)[1]/pii[1]/@pver">
                <xsl:value-of select="key('id',$RID)[1]/pii[1]/@pver"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$HTML-SPACE"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>

    <xsl:variable name="multiPolicy1">
        <xsl:call-template name="lookupMultiPolicy">
            <xsl:with-param name="flag" select="key('id',$RID)[1]/pii[1]/@druling"/>
        </xsl:call-template>
    </xsl:variable>

    <xsl:variable name="conformanceFlag">
        <xsl:call-template name="lookupConformanceFlag">
            <xsl:with-param name="flag" select="key('id',$RID)[1]/@result"/>
        </xsl:call-template>
    </xsl:variable>

  <!-- Emit Type Mappings segment header -->
   <xsl:call-template name="emitSmallSpacing"/>
   <xsl:variable name="subSectionLabel" select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_DETAILED_TYPEMAPS'))"/>
   <xsl:call-template name="emitHeader-Section">
       <xsl:with-param name="sectionTitle" select="$subSectionLabel"/>
   </xsl:call-template>               
   <xsl:call-template name="emitSmallSpacing"/>
  
   <TABLE borderColor="#bcbcbc" cellSpacing="0" cellPadding="2" width="96%" align="center" border="1">
   <TBODY>

      <!-- Emit storage location and privacy policy piitype header --> 
      <TR>            
         <TH width="{$ACCESS-TYPEMAP-SLOC-WIDTH}" rowspan="2" class="genericHeaderCellRpt"><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_TABLES_SLOC'))"/></TH>           
         <TH width="{$ACCESS-TYPEMAP-TYPE-WIDTH}" colspan="5" class="genericHeaderCellRpt"><CENTER><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_TABLES_TYPE'))"/></CENTER></TH>
         <TH width="{$ACCESS-TYPEMAP-CONFORMANCE-WIDTH}" rowspan="2" class="genericHeaderCellRpt"><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_TABLES_CONFORMANT'))"/></TH>        
      </TR>
       
      <TR>            
         <TH width="{$ACCESS-TYPEMAP-TYPE-NAME-WIDTH}" class="genericHeaderCellRpt"><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_TABLES_TYPE_NAME'))"/></TH>            
         <TH width="{$ACCESS-TYPEMAP-TYPE-POLICYNAME-WIDTH}" class="genericHeaderCellRpt"><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_TABLES_TYPE_POLICYNAME'))"/></TH>         
         <TH width="{$ACCESS-TYPEMAP-TYPE-POLICYVERSION-WIDTH}" class="genericHeaderCellRpt"><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_TABLES_TYPE_POLICYVERSION'))"/></TH>         
         <TH width="{$ACCESS-TYPEMAP-TYPE-CONSENT-WIDTH}" class="genericHeaderCellRpt"><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_TABLES_TYPE_CONSENT'))"/></TH> 
         <TH width="{$ACCESS-TYPEMAP-TYPE-MULTIPOLICY-WIDTH}" class="genericHeaderCellRpt"><xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_TABLES_TYPE_MULTIPOLICY'))"/></TH> 
      </TR>
         
      <TR>
         <TD class="genericTableCellRpt" rowspan="{$numTypes}"><xsl:value-of select="$slocName"/></TD>
         <TD class="genericTableCellRpt"><xsl:value-of select="$typeName1"/></TD>
         <TD class="genericTableCellRpt"><xsl:value-of select="$policyName1"/></TD>
         <TD class="genericTableCellRpt"><xsl:value-of select="$policyVersion1"/></TD>
         <TD class="genericTableCellRpt">

        <xsl:choose>
            <xsl:when test="key('id',$RID)[1]/pii[1]/@ctype='explicit' and key('id',$RID)[1]/@srtime != 0">

                <xsl:variable name="timestampConsent" select="key('id',$RID)[1]/@srtime"/>

                <xsl:variable name="dateTimeStringConsent">
                    <xsl:value-of select="localizer:formatDateShort($xsltLocalizer, string($timestampConsent))"/>
                    <xsl:value-of select="$HTML-SPACE"/>
                    <xsl:value-of select="localizer:formatTimeLong($xsltLocalizer, string($timestampConsent))"/>
                </xsl:variable>

                <xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_EXPLICIT_LINK'), $dateTimeStringConsent)"/>

            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="lookupPolicyConsent">
                    <xsl:with-param name="consent" select="key('id',$RID)[1]/pii[1]/@ctype"/>
                </xsl:call-template>
            </xsl:otherwise>
        </xsl:choose>

        </TD>
        <TD class="genericTableCellRpt"><xsl:value-of select="$multiPolicy1"/></TD>
        <TD class="genericTableCellRpt" rowspan="{$numTypes}"><xsl:value-of select="$conformanceFlag"/></TD>    
      </TR>


    <xsl:for-each select="key('id',$RID)[1]/pii[position()!=1]">

        <xsl:variable name="typeName">
            <xsl:choose>
                <xsl:when test="@type-name">
                    <xsl:value-of select="@type-name"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$HTML-SPACE"/>
                </xsl:otherwise>
            </xsl:choose> 
        </xsl:variable>

        <xsl:variable name="policyName">
            <xsl:choose>
                <xsl:when test="@pname">
                    <xsl:value-of select="@pname"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$HTML-SPACE"/>
                </xsl:otherwise>
            </xsl:choose> 
        </xsl:variable>

        <xsl:variable name="policyVersion">
            <xsl:choose>
                <xsl:when test="@pver">
                    <xsl:value-of select="@pver"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$HTML-SPACE"/>
                </xsl:otherwise>
            </xsl:choose> 
        </xsl:variable>

	    <xsl:variable name="multiPolicy">
	        <xsl:call-template name="lookupMultiPolicy">
	            <xsl:with-param name="flag" select="@druling"/>
	        </xsl:call-template>
	    </xsl:variable>

        <TR>
            <TD class="genericTableCellRpt"><xsl:value-of select="$typeName"/></TD>
            <TD class="genericTableCellRpt"><xsl:value-of select="$policyName"/></TD>
            <TD class="genericTableCellRpt"><xsl:value-of select="$policyVersion"/></TD>
            <TD class="genericTableCellRpt">

            <xsl:choose>
                <xsl:when test="@ctype='explicit' and ../@srtime != 0">

                    <xsl:variable name="timestampConsent" select="../@srtime"/>

                    <xsl:variable name="dateTimeStringConsent">
                        <xsl:value-of select="localizer:formatDateShort($xsltLocalizer, string($timestampConsent))"/>
                        <xsl:value-of select="$HTML-SPACE"/>
                        <xsl:value-of select="localizer:formatTimeLong($xsltLocalizer, string($timestampConsent))"/>
                    </xsl:variable>

                    <xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_EXPLICIT_LINK'), $dateTimeStringConsent)"/>

                </xsl:when>
                <xsl:otherwise>        
                    <xsl:call-template name="lookupPolicyConsent">
                        <xsl:with-param name="consent" select="@ctype"/>
                    </xsl:call-template>    
                </xsl:otherwise>
            </xsl:choose>

            </TD>
            <TD class="genericTableCellRpt"><xsl:value-of select="$multiPolicy"/></TD>
        </TR>

   </xsl:for-each>
   </TBODY>
   </TABLE>

</xsl:template>
</xsl:stylesheet>