<?xml version="1.0" encoding="UTF-8"?>
<!--
********************************************************************
*  Licensed Materials - Property of IBM 
*
*  5724-C07 
*
*  (c) Copyright IBM Corp.  2001, 2004 All Rights Reserved
* 
*  US Government Users Restricted Rights - Use, duplication or
*  disclosure restricted by GSA ADP Schedule Contract with
*  IBM Corp.
*********************************************************************

*********************************************************************
* File, Component, Release:
* %W%
*
* Version: %I%
*
* Date and Time File was last checked in:       %E% %U%
* Date and Time File was extracted/checked out: %D% %T%
*
* Description:
*
* Change History:
*
* mm/dd/yyyy userid   track    change history description here
* ********** ******   *****    **************************************
*            plachco  f6172    Intial Code Creation
* 02/02/2004 jharter  d6587    Add record count info messages
* 02/05/2004 jharter  d6634    Move record couning to detailed_access.xsl
*
*********************************************************************
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:lxslt="http://xml.apache.org/xslt"
                xmlns:localizer="xalan://com.ibm.btb.tools.archive.view.XSLTLocalizer"
                exclude-result-prefixes="localizer"
                version="1.0">

<!-- *********************************************************************** 
     Imports for individual report stylesheets
     *********************************************************************** -->
<xsl:import href="common.xsl"/>
<xsl:variable name="basedir"   select="'../'"/>
<xsl:variable name="relative"   select="localizer:getRootRelativeToSummaryPage($xsltLocalizer,$index)"/>
<xsl:param name="index"/>
<xsl:variable name="detailed-report-location" select="localizer:getDetailedPageRelativeToSummary($xsltLocalizer,$index)"/>
<xsl:variable name="title" select="localizer:getSummaryTitle($xsltLocalizer, $index)"/>

<!-- *********************************************************************** 
     Top-level element of all non-policy reports
     *********************************************************************** -->
<xsl:template match="pm-report">
    <xsl:apply-templates select="*"/>
</xsl:template>


<!-- *********************************************************************** 
     Report contents element - match it to the report-type specific stylesheets.
     *********************************************************************** -->
<xsl:template match="report-contents">
    <xsl:apply-templates select="*"/>
</xsl:template>

<!-- *********************************************************************** 
     Keys
     *********************************************************************** -->
<xsl:key name="id" match="ar" use="@id"/>
<xsl:key name="monitorUID" match="req" use="minfo/@muid"/>
<xsl:key name="purposeHash" match="ppurpose" use="concat(../../ar/@id,@name)"/>

<!-- *********************************************************************** 
     Main report element for access reports.
     *********************************************************************** -->
<xsl:template match="access-report">
   <TABLE cellspacing="0" cellpadding="0" width="100%" border="0">
       <TR>
         <TD align="middle" width="100%">
            <FONT class="title"><xsl:value-of select="$title"/></FONT>
          </TD>
       </TR>
   </TABLE>
   <BR/>
   <xsl:choose>
      <!-- At least one Access Request exists across all monitors -->
      <xsl:when test="req">
         <xsl:for-each select="req[generate-id(.)=generate-id(key('monitorUID',minfo/@muid)[1])]">
            <xsl:sort select="minfo/@mname" order="ascending"/>
            <xsl:sort select="minfo/@mregdate" order="ascending"/>

            <xsl:variable name="monitor" select="minfo/@muid"/>
            <xsl:variable name="mregdate" select="minfo/@mregdate"/>
            
            <xsl:variable name="mregdate-string">
               <xsl:value-of select="localizer:formatDateShort($xsltLocalizer, string($mregdate))"/>
               <xsl:value-of select="$HTML-SPACE"/>
               <xsl:value-of select="localizer:formatTimeLong($xsltLocalizer, string($mregdate))"/>
            </xsl:variable>               
            
            <xsl:if test="../req[minfo/@muid=$monitor and ar]">               
               <!-- Access Section Header -->
               <xsl:variable name="monitorName" select="minfo/@mname"/>
               <xsl:variable name="accessLabel" select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_ACCESS_HEADING'), $monitorName,$mregdate-string)"/>

               <xsl:call-template name="emitHeader-Section">
                  <xsl:with-param name="sectionTitle" select="$accessLabel"/>
               </xsl:call-template>               
               <xsl:call-template name="emitSmallSpacing"/>
                  <TABLE align="center" cellpadding="0" cellspacing="0" border="0" width="94%">
                     <TR>
                        <TD>
                           <TABLE align="center" cellpadding="2" cellspacing="0" bordercolor="#bcbcbc" border="1" width="100%">
                              <TR>
                                 <TH class="genericHeaderCellRpt">
	                                <xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_ACCESS_SUMMARY_DATE'))"/>
                                 </TH>
                                 <TH class="genericHeaderCellRpt">
	                                <xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_ACCESS_SUMMARY_PIIOWNER'))"/>
                                 </TH>
                                 <TH class="genericHeaderCellRpt">
	                                <xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_ACCESS_SUMMARY_SLOC'))"/>                  				
                                 </TH>
				                 <TH class="genericHeaderCellRpt">
	                                <xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_ACCESS_SUMMARY_PIIRECIPIENT'))"/>                  				
				                 </TH>
				                 <TH class="genericHeaderCellRpt">
	                                <xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_ACCESS_SUMMARY_PURPOSES'))"/>                  				
				                 </TH>
                                 <TH class="genericHeaderCellRpt">
	                                <xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_ACCESS_SUMMARY_CONFORMANT'))"/>                  				
                                 </TH>
                              </TR>               
               <!-- All Access Requests for Current Monitor -->                
               <xsl:apply-templates select="../req[minfo/@muid=$monitor and ar]"/>
                           </TABLE>
                        </TD>
                     </TR>
                  </TABLE>               
               <xsl:call-template name="emitSpacing-Section"/>                           
            </xsl:if>                    
         </xsl:for-each>
      </xsl:when>
      <!-- No Submission or Access Requests whatsoever (across all monitors)-->
      <xsl:otherwise>
         <!-- Access Section (EMPTY) -->
         <xsl:call-template name="accessSectionEmpty"/>
         <xsl:call-template name="emitSpacing-Section"/>       
      </xsl:otherwise>
   </xsl:choose>
</xsl:template>

<!-- *************************************************************************************************************
     *                                       ACCESS  RECORD  REQUEST                                             *
     *************************************************************************************************************-->
<xsl:template match="req[self::node()/ar]">        

    <xsl:variable name="access-time" select="@server-time"/>
    
    <xsl:variable name="accessDateTimeString">
        <xsl:value-of select="localizer:formatDateShort($xsltLocalizer, string($access-time))"/>
        <xsl:value-of select="$HTML-SPACE"/>
        <xsl:value-of select="localizer:formatTimeLong($xsltLocalizer, string($access-time))"/>    
    </xsl:variable>
    
    <!-- Retrieve matching authid contained in the ar -->
    <xsl:variable name="accessIdString">
        <xsl:choose>
          <xsl:when test="authid-info/@authid and (string-length(authid-info/@authid) != 0)">
              <xsl:value-of select="authid-info/@authid"/>
          </xsl:when>
          <xsl:otherwise>
              <xsl:value-of select="$HTML-SPACE"/>
          </xsl:otherwise>
        </xsl:choose> 
    </xsl:variable>
   
    <!-- Retrieve matching purposes contained in the ar -->
    <xsl:variable name="purposesString">
       <xsl:apply-templates select="purpose"/>
    </xsl:variable>
    
    <!-- Emit storage location and privacy policy information for this access record -->    
    <xsl:apply-templates select="ar">
        <xsl:with-param name="accessTimestamp" select="$accessDateTimeString"/>
        <xsl:with-param name="authid" select="$accessIdString"/>
        <xsl:with-param name="purposes" select="$purposesString"/>
        <xsl:with-param name="masterKeyValue" select="@mkval"/>
    </xsl:apply-templates>
    
</xsl:template>              

<!-- *************************************************************************************************************
     *                                          ACCESS   RECORD                                                  *
     *************************************************************************************************************-->
<xsl:template match="ar">
    <xsl:param name="accessTimestamp" select="$HTML-SPACE"/>
    <xsl:param name="authid" select="$HTML-SPACE"/>
    <xsl:param name="purposes" select="$HTML-SPACE"/>
    <xsl:param name="masterKeyValue" select="$HTML-SPACE"/>

    <xsl:variable name="slocName">
        <xsl:choose>
            <xsl:when test="@slname">
                <xsl:value-of select="@slname"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$HTML-SPACE"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    
    <xsl:variable name="conformanceFlag">
        <xsl:call-template name="lookupConformanceFlag">
            <xsl:with-param name="flag" select="@result"/>
        </xsl:call-template>
    </xsl:variable>
    
    <TR>
       <TD class="genericTableCellRpt"><a href="{$detailed-report-location}#{@id}"><xsl:value-of select="$accessTimestamp"/></a></TD>
       <TD class="genericTableCellRpt"><xsl:value-of select="$masterKeyValue"/></TD>      
       <TD class="genericTableCellRpt"><xsl:value-of select="$slocName"/></TD>
       <TD class="genericTableCellRpt"><xsl:value-of select="$authid"/></TD>
       <TD class="genericTableCellRpt"><xsl:value-of select="$purposes"/></TD>
       <TD class="genericTableCellRpt"><xsl:value-of select="$conformanceFlag"/></TD>
    </TR>
    
</xsl:template>

<!-- *************************************************************************************************************
     *                                         PURPOSE   INFO                                                    *
     *************************************************************************************************************-->
<xsl:template match="purpose">
      
      <xsl:choose>
      <xsl:when test="ppurpose">
	      <xsl:for-each select="ppurpose[generate-id(.)=generate-id(key('purposeHash',concat(../../ar/@id,@name))[1])]">
	          
	          <!-- Retrieve purpose name for the current ppurpose element -->
	          <xsl:variable name="purposeName">
	              <xsl:choose>
	                  <xsl:when test="@name and (string-length(@name) != 0)">
	                      <xsl:value-of select="@name"/>
	                  </xsl:when>
	                  <xsl:otherwise>
	                      <xsl:value-of select="$HTML-SPACE"/>
	                  </xsl:otherwise>
	              </xsl:choose> 
	          </xsl:variable>
	          
	          <xsl:choose>                
	              <!-- The very first element includes the purpose key and value -->
	              <xsl:when test="position()=1">		                        
	                  <xsl:value-of select="$purposeName"/>
	              </xsl:when>                    
	              <!-- The 2nd,3rd,etc elements have a comma -->
	              <xsl:otherwise>
	                  <xsl:text>,</xsl:text><xsl:value-of select="$purposeName"/>
	              </xsl:otherwise>                    
	          </xsl:choose>                
	          
	      </xsl:for-each>                                 
      </xsl:when>
      <xsl:otherwise>
          <xsl:value-of select="$HTML-SPACE"/>
      </xsl:otherwise>
      </xsl:choose>		      

</xsl:template>
<!-- *************************************************************************************************************
     *                                          EMPTY   SECTIONS                                                 *
     *************************************************************************************************************-->
   <xsl:template name="accessSectionEmpty"> 
           
       <xsl:variable name="accessLabel" select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_ACCESS_HEADING_NONE'))"/>
       <xsl:call-template name="emitHeader-Section">
           <xsl:with-param name="sectionTitle" select="$accessLabel"/>
       </xsl:call-template>    
           
       <xsl:call-template name="emitSmallSpacing"/>
   
       <!-- Emit table header -->           
      <TABLE align="center" cellpadding="0" cellspacing="0" border="0" width="94%">
         <TR>
            <TD>
               <TABLE align="center" cellpadding="2" cellspacing="0" bordercolor="#bcbcbc" border="1" width="100%">
                  <TR>
                     <TH class="genericHeaderCellRpt">
                        <xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_ACCESS_SUMMARY_DATE'))"/>
                     </TH>
                  <xsl:if test="name(.)='global-access-report'">
                     <TH class="genericHeaderCellRpt">
                        <xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_ACCESS_SUMMARY_PIIOWNER'))"/>
                     </TH>
                  </xsl:if>
                     <TH class="genericHeaderCellRpt">
                        <xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_ACCESS_SUMMARY_SLOC'))"/>                  				
                     </TH>
	                 <TH class="genericHeaderCellRpt">
                        <xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_ACCESS_SUMMARY_PIIRECIPIENT'))"/>                  				
	                 </TH>
	                 <TH class="genericHeaderCellRpt">
                        <xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_ACCESS_SUMMARY_PURPOSES'))"/>                  				
	                 </TH>
                     <TH class="genericHeaderCellRpt">
                        <xsl:value-of select="localizer:getString($xsltLocalizer, string('KEY_ACCESSRPT_ACCESS_SUMMARY_CONFORMANT'))"/>                  				
                     </TH>
                  </TR>               
                  <TR>
                      <TD colspan="6"><xsl:value-of select="$HTML-SPACE"/></TD>
		          </TR>
               </TABLE>
            </TD>
         </TR>
      </TABLE>               
   
   </xsl:template>

</xsl:stylesheet>